@@ -1,7 +1,6 @@
 package Storm::Role::Query::HasOrderByClause;
 
 use Moose::Role;
-use MooseX::Method::Signatures;
 use MooseX::Types::Moose qw( ArrayRef );
 
 with 'Storm::Role::Query::HasAttributeMap';
@@ -20,7 +19,8 @@ has '_order_by' => (
     }
 );
 
-method order_by ( @args ) {
+sub order_by {
+    my ( $self, @args ) = @_;
     my @elements;
     my $map = $self->_attribute_map;
     
@@ -36,7 +36,8 @@ method order_by ( @args ) {
     return $self;
 }
 
-method _order_by_clause {
+sub _order_by_clause {
+    my ( $self ) = @_;
     return if $self->_has_no_order_by_elements;
     
     my $sql = 'ORDER BY ';
@@ -50,3 +51,27 @@ method _order_by_clause {
 no Moose::Role;
 
 1;
+
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Storm::Role::Query::HasOrderByClause - Role for queries with an ORDER BY clause
+
+=head1 AUTHOR
+
+Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
+
+Modified from code in Dave Rolsky's L<Fey> module.
+
+=head1 COPYRIGHT
+
+    Copyright (c) 2010 Jeffrey Ray Hallock. All rights reserved.
+    This program is free software; you can redistribute it and/or
+    modify it under the same terms as Perl itself.
+
+=cut
+
